extensions [table]

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; global and turtle variables
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

globals [issue-dict]
; issue dict is a dictionary (table) where the keys are issues (strings of 0s and 1s)
;            and the values are lists of agent who numbers. Should be updated after
;            any change to an agent's issue.

turtles-own [issue novelty num-meaningful num-interactions social-modifier]
; issue is a list of 0s and 1s of length issue-size.
; novelty is a float between 0.0 and 0.5. The probability of choosing the agent's top
;         choice is 1.0 - novelty.
; num-meaningful is the number of meaningful interactions the agent has counted
; num-interactions is the number of interactions the agent has participated in


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; main procedures
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to setup
  ; initializes the simulation
  clear-all

  ; create the issue-dict table
  set issue-dict table:make

  ; initialize the agents
  set-default-shape turtles "person"
  create-turtles number-of-agents [
    init-issue
    set novelty 0.0
    set num-meaningful 0
    set num-interactions 0
    set social-modifier 0
    update-graphics
  ]

  layout-circle turtles (world-width / 2.5 - 1)
  reset-ticks
end

to go
  ; called every tick
  ask turtles [
    let chosen-who choose

    if (chosen-who != who) [
      interact-with chosen-who

      ask my-out-links [die]
      create-link-to turtle chosen-who

      update-graphics
    ]
  ]
  layout-spring turtles links 0.2 5 1
  tick
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; procedures related to choosing an agent to interact with
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to-report choose
  ; reports the who number of an agent
  ; this who number represents the agent's choice in interaction based on
  ; similarity and novelty

  ; rank issue codes based on similarity
  let sim-rank issue-similarity-ranking

  ; choose an issue code to seek out using novelty
  ; using while instead of foreach to make sure
  ; ranking is preserved (being extra careful here)
  let i 0
  while [i < length sim-rank] [
    if (random-float 1.0) <= (1.0 - novelty) [
      let issue-choice item 0 (item i sim-rank)
      let agents table:get issue-dict issue-choice
      report one-of agents
    ]
    set i (i + 1)
  ]

  ; no choice was made, so just choose your own issue
  let issue-choice item 0 (item 0 sim-rank)
  let agents table:get issue-dict issue-choice
  report one-of agents
end

to-report issue-similarity-ranking
  ; reports a list of tuples (lists) of the form (issue, similarity)
  ; sorted from highest to lowest similarity
  ; the list does not include issues not currently represented by an agent

  let sim-rank []

  let issues shuffle table:keys issue-dict

  foreach issues [ i ->
    set sim-rank lput (list i (similarity issue i)) sim-rank
  ]

  set sim-rank sort-by [ [c1 c2] -> (item 1 c1) > (item 1 c2) ] sim-rank

  report sim-rank
end

to-report similarity [issue1 issue2]
  ; reports the similarity of two issues

  report length filter [i -> i] (map = issue1 issue2)
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; procedures related to agent interaction
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to interact-with [who-number]
  ; interact with the agent with who number who-number
  ; after this procedure finishes, the agent's issue may have been changed
  ; this procedure handles all of the required updates to the issues
  let my-issue issue
  let new-issue []
  set num-interactions (num-interactions + 1)
  set social-modifier max list (-1 * value-of-social-popularity) (social-modifier - 1)

  ask turtle who-number [
    ; generate a new-issue using the agents' issues
    set new-issue issue-combine my-issue issue
    set num-interactions (num-interactions + 1)
    set social-modifier min list value-of-social-popularity (social-modifier + 1)

    ; check to see if the agent should update its issue
    (ifelse (accept-new-issue? new-issue) [
      update-issue new-issue
      reset-novelty
      set num-meaningful (num-meaningful + 1)
    ] [
      increase-novelty
    ])
  ]

  ; check to see if the agent should update its issue
  (ifelse (accept-new-issue? new-issue) [
    update-issue new-issue
    reset-novelty
    set num-meaningful (num-meaningful + 1)
   ] [
    increase-novelty
   ])
end

to-report accept-new-issue? [new-issue]
  ; determines whether or not the agent should accept the new issue
  let fit fitness issue
  let new-fit fitness new-issue
  report new-fit > (fit + social-modifier)
end

to-report issue-combine [issue1 issue2]
  ; reports a new issue resulting from combining issue1 and issue2
  report (map bit-combine issue1 issue2)
end

to-report bit-combine [i j]
  ; reports a bit resulting from combining bits i and j

  if i = j [
    report i
  ]

  report random 2
end

to-report fitness [i]
    let r sum i
    let b (number-of-agent-issues - r)
    report max list r b
end

to-report max-fitness
  report number-of-agent-issues
end

to-report Percentage-of-agents-in-Non-Fitness-Oriented-Groups
  report 1
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; helper procedures for agent variables
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to reset-novelty
  ; set the novelty to 0.0
  set novelty 0.0
end

to increase-novelty
  ; increase novelty by value-in-novelty (max is 0.5)
  set novelty min list 0.5 (novelty + value-of-novelty)
end

to init-issue
  ; sets the agent's issue to a random string of 0s and 1s
  let new-issue n-values number-of-agent-issues [random 2]
  update-issue new-issue
end

to update-issue [new-issue]
  ; updates the agent's current issue to a new issue string
  ; updates issue-dict and sim-ranking
  ; always call this procedure instead of updating the issue directly
  ; new-issue: the new issue string

  put-issue-dict new-issue
  set issue new-issue
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; helper procedures for issue-dict
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to put-issue-dict [new-issue]
  ; updates issue-dict
  ; does not modify agent's issue variable

  ; remove agent from its current position in the table
  if (table:has-key? issue-dict issue) [
    let agents table:get issue-dict issue
    set agents remove who agents
    (ifelse (empty? agents) [
      table:remove issue-dict issue
    ] [
      table:put issue-dict issue agents
    ])
  ]

  ; insert agent into new position in the table
  let agents []
  if (table:has-key? issue-dict new-issue) [
    set agents table:get issue-dict new-issue
  ]
  set agents lput who agents
  table:put issue-dict new-issue agents
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; NEED TO BE ORGANIZED
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
to update-graphics
    let x ((sum issue) / number-of-agent-issues)
    let r max list 50 (floor 255.0 * x)
    let g 50
    let b max list 50 (floor 255.0 * (1.0 - x))
    set color (list r g b)
    set size max list 1 (4.0 * (social-modifier + max-fitness) / (2 * max-fitness))
end

to-report issue-to-decimal [i]
  ; reports the numerical value of the issue i (in decimal)

  let v (2 ^ ((length i) - 1))
  let value 0
  foreach i [ d ->
    set value (value + v * d)
    set v (v / 2)
  ]

  report value
end
@#$#@#$#@
GRAPHICS-WINDOW
210
10
902
703
-1
-1
20.73
1
10
1
1
1
0
0
0
1
-16
16
-16
16
0
0
1
ticks
30.0

BUTTON
142
10
205
43
NIL
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

PLOT
909
10
1109
158
Number of groups
time
groups
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" "plot table:length issue-dict"

PLOT
910
163
1110
313
Size of each group
group
size
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"default" 1.0 1 -16777216 true "" "clear-plot\nforeach table:keys issue-dict [ i ->\n  plotxy (issue-to-decimal i) length table:get issue-dict i\n]\n\n"

SLIDER
7
157
208
190
value-of-social-popularity
value-of-social-popularity
0
10
9.0
1
1
NIL
HORIZONTAL

SLIDER
7
120
207
153
value-of-novelty
value-of-novelty
0
0.5
0.01
.01
1
NIL
HORIZONTAL

SLIDER
8
47
205
80
number-of-agents
number-of-agents
0
150
150.0
1
1
NIL
HORIZONTAL

SLIDER
8
84
207
117
number-of-agent-issues
number-of-agent-issues
1
10
10.0
1
1
NIL
HORIZONTAL

BUTTON
6
10
72
43
setup
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
76
10
139
43
step
go
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

@#$#@#$#@
## WHAT IS IT?

This model illustrates the processes underlying the social construction of reality through an agent-based genetic algorithm. By simulating the interactions of agents within a structured environment, we have demonstrated how shared information and popularity contribute to the formation of emergent social structures with diverse cultures. The model illustrates how agents balance environmentally valid information with socially reliable information. It also highlights how social interaction leads to the formation of stable, yet diverse, social groups.

## HOW IT WORKS

This protocol provides a detailed description of the social construction of a reality agent-based model, following the guidelines set out by Grimm et al. (2006, 2010, 2020), to ensure clarity, reproducibility, and comprehensiveness.

### A. Overview


#### 1. Purpose and Patterns

**Purpose:** The primary purpose of the Social Construction of Reality Model is to illustrate how social interactions among agents can lead to the emergence of shared realities or cultures. This model investigates the balance between environmental fitness and social popularity in shaping self-organizing communities, aiming to provide insights into the dynamics of information diffusion and cultural convergence.

**Patterns:** The model evaluates its purpose by reproducing the following patterns:
Emergence of stable networks of agents sharing similar information, indicated by color changes. Formation of groups based on shared cultural information, reflecting both environmental fitness and social popularity dynamics.

#### 2. Entities, State Variables, and Scales

##### Entities:
**Agents**: Represent social actors who store and share information. Each agent has attributes such as information, capacity, and popularity.
Information: Discrete objects representing knowledge units that agents exchange.

##### State Variables:

**Agents:**
- Information: A vector summarizing knowledge (indicated by color).
- Capacity: Maximum amount of information an agent can hold.
- Popularity: Frequency of selection for interaction (indicated by size).

**Scales:**
- Temporal: Each simulation step represents an interaction event.
- Spatial: Agents are placed in a 2D grid where proximity affects interaction likelihood.

#### 3. Process Overview and Scheduling

Process Overview:
- Agents interact based on the similarity and novelty of information.
- Information sharing occurs during interactions, leading to changes in agent knowledge and popularity.

##### Scheduling:
**Initialization:**
- Agents are randomly distributed with a random set of information.

**Repeatedly:**
- Agents select partners based on information similarity and novelty.
- Agents exchange information related to the chosen topic, updating their knowledge.
- Agents' popularity is updated based on the frequency of their selection for interaction.

### B. Design Concepts

**Basic Principles:** The model is grounded in social interaction theories, highlighting how agent behaviors and information exchanges contribute to the emergence of shared realities. The principles include:

- Social interactions and information sharing drive the emergence of shared realities.
- Agents balance the pursuit of environmental fitness (novel information) and social reliability (popular information).

**Emergence: **Stable groups form based on shared cultural information. Interaction patterns reflect both environmental and social influences.

**Adaptation:** Agents adapt by updating their knowledge based on interactions.

**Objectives:** Agents aim to increase their fitness by acquiring novel, environmentally valid information while maintaining socially reliable information.

**Learning:** The model does not include learning mechanisms.

**Prediction:** The model predicts the formation of stable social structures based on information dynamics.

**Sensing:** Agents sense the information and popularity of other agents.

**Interaction:** Agents choose partners based on the similarity and novelty of their information.

**Stochasticity:** Randomness is introduced in the initialization and interaction processes to simulate variability.

**Collectives:** Groups of agents with similar information emerge as collective entities.

**Observation:** The model tracks changes in agent information (color) and popularity (size) over time.

### C. Details 

#### 1. Initialization: 

Agents are initialized with random sets of information, distributed randomly in the 2D grid.

#### 2. Input Data: 

No external input data is used; all information is generated within the model.

#### 3. Submodels

Agents interact based on their state. They have states that vary depending on their interaction. Agents are attracted to similar agents. They also take popularity into consideration. Agents can be paired with dissimilar agents based on a growing degree of novelty.

**​​Agents are represented by Issues:** Each agent, composed of zeroes and ones, is in a particular state, composed of its current configuration, as well as the fitness of the configuration. On every turn, an agent “chooses” to interact with another agent. Agents generally prefer to interact with similar agents. Once paired, an agent may choose to update their state to the new combined state resulting from the interaction.  

An issue is a nonempty set S of symbols. The symbols represent the possible states an issue could be in. Issues can be of different sizes. 

**Example:** ​​The agents can only transition from S1 to S2, but not from S2 back to S1. Notice that while agents are in S1, they can only see the first three bits. When they transition to S2, they are able to work on the entire five bits. When they transition, they keep the bits they had from S1 and add a random collection of bits as needed.
 
For example, if an agent is in state 011?? and they transition to S2, then they will randomly be assigned to one of {01100, 01101, 01110, 01111}.

Agents in S1 are represented as people, and agents in S2 are represented as people carrying a briefcase. An agent could transition to a new information space once a certain fitness value is achieved. In the different set ups of our model, agents transition from the first state S1, to the second state S2, when a combination of its fitness and its popularity surpass a certain threshold.

**Interaction Partner Selection:** Agents evaluate potential partners based on the combined score of similarity and novelty.
Each agent must select another agent. The two agents must interact and may update their issue states. Both agent’s information space may transition to a new space.

**Information Sharing:** During interaction, agents share information related to the chosen topic, updating their knowledge. Popular agents (positive social-modifier) will appear large in the visualization, and unpopular agents (negative social-modifier) will appear small. If an agent chooses another agent for interaction, we subtract one from their social modifier. If an agent is chosen by another agent for interaction, we add one to their social modifier. We cap the social-modifer by keeping it between the values:

max-social-modifer < social-modifier < max-social-modifier

Agents' popularity is updated based on the frequency of their selection for interaction. Just like with a traditional Genetic Algorithm, each configuration is assigned a fitness value.
 
**Fitness Functions:** Red vs. Blue fitness function is currently available in the model. This fitness function is defined to be the maximum of (number of ones) and (number of zeroes). For example, f(00011) = 3, f(01011) = 3, f(101??) = 2, f(00000) = 5, f(11111) = 5. Notice that there are two ways to achieve maximum fitness: all ones or all zeros. Each zero in the bit string causes the agent to appear more blue, and each one causes the agent to appear more red.

Our model uses the concepts of similarity and novelty for interaction. In this model, similarity is defined to be how many bits two bit strings have in common. Novelty is defined to be a probability intended to represent the chance of an agent branching out to new agents for interaction. Without novelty, agents would always choose to interact with the agent most similar to them.

For every bit string b that is held by some agent, we compute similarity. All the bit strings are listed in order of their similarity with the highest similarity being first on the list. 

**Example:** Let p = 1 - novelty, where novelty is the agent A’s current novelty. Suppose we have a coin with probability p of landing heads. Flip the coin. If heads, stop. If tails, flip again. If we flip the coin once, select bit string b1. If we flip the coin twice, select bit string b2. If we flip the coin n times, select bit string bn.

**Popularity Update:** Agents' popularity is updated based on the frequency of their selection for interaction. When two agents, A & B interact, their states (a & b) combine to produce a third state (c). If A and B agree on a bit, the bit is copied. If they disagree, a random one or zero is used. If there is an interaction between agents in different states (S1 and S2), then the agent in the higher state maintains its bits in S2. Once each agent receives the resulting c string, we must determine whether or not they will accept or reject c as their new issue state. Agent A will accept the string c if:

fitness(c) > (fitness(a) + social-modifier(A))

If agent A accepts the string, this is called a meaningful interaction, and agent A’s novelty is set to 0.0. If agent A rejects the string, then agent A’s novelty is modified by setting: 

novelty = novelty + change-in-novelty

This means that the more consecutive unmeaningful interactions an agent has, the higher their desire for novelty becomes. This makes them more likely to branch out in search of meaningful interactions. This prevents agents from getting “stuck” in groups of similar agents.


## HOW TO USE IT

Use number-of-agents to increase or decrease the number of agents.
Use number-of-agent-issues to establich the internal information size in each agent.
Use value-of-novelty to setup the novelty weigth in agent interaction.
Use value-of-social-popularity to setup the popularity weigth in agent interaction.
Run by step or continue ticks execution pressing step or go.
Se the Number of groups and the size of Size of each group in the plots.

## THINGS TO NOTICE

The model aims to show the appearance of emergent groups that are not fully blue or red, therefore not directly responding to the fitness function, but rather to the "echo effect" of their own interactions. Find the model configurations that create the longest lasting cliques of emergent groups. 

## THINGS TO TRY

The model leverages the two forces that are create emergent behavior: novelty and popularity. Play with these two variables to see the effects they have on group formation and group longevity. 

## EXTENDING THE MODEL

This version of the model focuses on one particular fitness function that creates the blue and red groups. Other fitness functions can be used to explore similar configurations, and specific implementations of the model to fit real-world phenomena. 


## RELATED MODELS

Stonedahl, F. and Wilensky, U. (2008). NetLogo Simple Genetic Algorithm model. http://ccl.northwestern.edu/netlogo/models/SimpleGeneticAlgorithm. Center for Connected Learning and Computer-Based Modeling, Northwestern University, Evanston, IL.

Wilensky, U. (2004). NetLogo Heatbugs model. http://ccl.northwestern.edu/netlogo/models/Heatbugs. Center for Connected Learning and Computer-Based Modeling, Northwestern University, Evanston, IL.

Nanda Wijermans, Helen Fischer (2022, October 28). “AgentEx-Meta” (Version 1.0.0). CoMSES Computational Model Library. Retrieved from: https://doi.org/10.25937/cs13-mr12

## CREDITS AND REFERENCES
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270
@#$#@#$#@
NetLogo 6.4.0
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180
@#$#@#$#@
0
@#$#@#$#@
